{% load i18n %}{% spaceless %}
{% with node=task.get_node %}

#### {{ task.status }} = flow.{{ node.node_name }}() {% if task.finished %}{{ task.finished }}{% else %}{% trans "running" %}{% endif %}

{% if node.description %}

{{ node.description }}

{% endif %} {% if task.message == "OK" and task.result %}

    {{ task.result }}

{% elif "Error" in task.message %} `{{ task.message }}` {% else %}

    {{ task.message }}

{% endif %}
{% if node.modifiers %}
{% endif %} {% endwith %}
{% endspaceless %}